Class: Aws::ElasticLoadBalancingV2::Types::LoadBalancerState
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticLoadBalancingV2::Types::LoadBalancerState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticloadbalancingv2/types.rb
Overview
Information about the state of the load balancer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The state code.
-
#reason ⇒ String
A description of the state.
Instance Attribute Details
#code ⇒ String
The state code. The initial state of the load balancer is provisioning. After the load balancer is fully set up and ready to route traffic, its state is active. If load balancer is routing traffic but does not have the resources it needs to scale, its state is`active_impaired`. If the load balancer could not be set up, its state is failed.
2801 2802 2803 2804 2805 2806 |
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 2801 class LoadBalancerState < Struct.new( :code, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A description of the state.
2801 2802 2803 2804 2805 2806 |
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 2801 class LoadBalancerState < Struct.new( :code, :reason) SENSITIVE = [] include Aws::Structure end |