Class: Aws::ElasticLoadBalancingV2::Types::ModifyListenerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticloadbalancingv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alpn_policyArray<String>

[TLS listeners] The name of the Application-Layer Protocol Negotiation (ALPN) policy. You can specify one policy name. The following are the possible values:

  • HTTP1Only

  • HTTP2Only

  • HTTP2Optional

  • HTTP2Preferred

  • None

For more information, see [ALPN policies] in the *Network Load Balancers Guide*.

[1]: docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-listeners.html#alpn-policies

Returns:

  • (Array<String>)


3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#certificatesArray<Types::Certificate>

[HTTPS and TLS listeners] The default certificate for the listener. You must provide exactly one certificate. Set CertificateArn to the certificate ARN but do not set IsDefault.

Returns:



3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#default_actionsArray<Types::Action>

The actions for the default rule.

Returns:



3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#listener_arnString

The Amazon Resource Name (ARN) of the listener.

Returns:

  • (String)


3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#mutual_authenticationTypes::MutualAuthenticationAttributes

[HTTPS listeners] The mutual authentication configuration information.



3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port for connections from clients to the load balancer. You can’t specify a port for a Gateway Load Balancer.

Returns:

  • (Integer)


3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol for connections from clients to the load balancer. Application Load Balancers support the HTTP and HTTPS protocols. Network Load Balancers support the TCP, TLS, UDP, TCP_UDP, QUIC, and TCP_QUIC protocols. You can’t change the protocol to UDP, TCP_UDP, QUIC, or TCP_QUIC if dual-stack mode is enabled. You can’t specify a protocol for a Gateway Load Balancer.

Returns:

  • (String)


3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end

#ssl_policyString

[HTTPS and TLS listeners] The security policy that defines which protocols and ciphers are supported.

For more information, see [Security policies] in the *Application Load Balancers Guide* or [Security policies] in the *Network Load Balancers Guide*.

[1]: docs.aws.amazon.com/elasticloadbalancing/latest/application/describe-ssl-policies.html [2]: docs.aws.amazon.com/elasticloadbalancing/latest/network/describe-ssl-policies.html

Returns:

  • (String)


3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 3042

class ModifyListenerInput < Struct.new(
  :listener_arn,
  :port,
  :protocol,
  :ssl_policy,
  :certificates,
  :default_actions,
  :alpn_policy,
  :mutual_authentication)
  SENSITIVE = []
  include Aws::Structure
end