Class: Aws::ElasticLoadBalancingV2::Types::SetSubnetsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticloadbalancingv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_prefix_for_ipv_6_source_natString

[Network Load Balancers with UDP listeners] Indicates whether to use an IPv6 prefix from each subnet for source NAT. The IP address type must be dualstack. The default value is off.



4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4087

class SetSubnetsInput < Struct.new(
  :load_balancer_arn,
  :subnets,
  :subnet_mappings,
  :ip_address_type,
  :enable_prefix_for_ipv_6_source_nat)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_typeString

The IP address type.

[Application Load Balancers] The possible values are ipv4 (IPv4 addresses), dualstack (IPv4 and IPv6 addresses), and dualstack-without-public-ipv4 (public IPv6 addresses and private IPv4 and IPv6 addresses).

[Network Load Balancers and Gateway Load Balancers] The possible values are ipv4 (IPv4 addresses) and dualstack (IPv4 and IPv6 addresses).



4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4087

class SetSubnetsInput < Struct.new(
  :load_balancer_arn,
  :subnets,
  :subnet_mappings,
  :ip_address_type,
  :enable_prefix_for_ipv_6_source_nat)
  SENSITIVE = []
  include Aws::Structure
end

#load_balancer_arnString

The Amazon Resource Name (ARN) of the load balancer.



4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4087

class SetSubnetsInput < Struct.new(
  :load_balancer_arn,
  :subnets,
  :subnet_mappings,
  :ip_address_type,
  :enable_prefix_for_ipv_6_source_nat)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_mappingsArray<Types::SubnetMapping>

The IDs of the public subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings.

[Application Load Balancers] You must specify subnets from at least two Availability Zones. You can’t specify Elastic IP addresses for your subnets.

[Application Load Balancers on Outposts] You must specify one Outpost subnet.

[Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.

[Network Load Balancers] You can specify subnets from one or more Availability Zones. You can specify one Elastic IP address per subnet if you need static IP addresses for your internet-facing load balancer. For internal load balancers, you can specify one private IP address per subnet from the IPv4 range of the subnet. For internet-facing load balancer, you can specify one IPv6 address per subnet.

[Gateway Load Balancers] You can specify subnets from one or more Availability Zones.



4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4087

class SetSubnetsInput < Struct.new(
  :load_balancer_arn,
  :subnets,
  :subnet_mappings,
  :ip_address_type,
  :enable_prefix_for_ipv_6_source_nat)
  SENSITIVE = []
  include Aws::Structure
end

#subnetsArray<String>

The IDs of the public subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings.

[Application Load Balancers] You must specify subnets from at least two Availability Zones.

[Application Load Balancers on Outposts] You must specify one Outpost subnet.

[Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.

[Network Load Balancers] You can specify subnets from one or more Availability Zones.

[Gateway Load Balancers] You can specify subnets from one or more Availability Zones. You must include all subnets that were enabled previously, with their existing configurations, plus any additional subnets.



4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4087

class SetSubnetsInput < Struct.new(
  :load_balancer_arn,
  :subnets,
  :subnet_mappings,
  :ip_address_type,
  :enable_prefix_for_ipv_6_source_nat)
  SENSITIVE = []
  include Aws::Structure
end