Class: Aws::ElasticLoadBalancingV2::Types::TargetHealthDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticloadbalancingv2/types.rb

Overview

Information about the health of a target.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#administrative_overrideTypes::AdministrativeOverride

The administrative override information for the target.



4826
4827
4828
4829
4830
4831
4832
4833
4834
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4826

class TargetHealthDescription < Struct.new(
  :target,
  :health_check_port,
  :target_health,
  :anomaly_detection,
  :administrative_override)
  SENSITIVE = []
  include Aws::Structure
end

#anomaly_detectionTypes::AnomalyDetection

The anomaly detection result for the target.

If no anomalies were detected, the result is normal.

If anomalies were detected, the result is anomalous.



4826
4827
4828
4829
4830
4831
4832
4833
4834
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4826

class TargetHealthDescription < Struct.new(
  :target,
  :health_check_port,
  :target_health,
  :anomaly_detection,
  :administrative_override)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_portString

The port to use to connect with the target.

Returns:

  • (String)


4826
4827
4828
4829
4830
4831
4832
4833
4834
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4826

class TargetHealthDescription < Struct.new(
  :target,
  :health_check_port,
  :target_health,
  :anomaly_detection,
  :administrative_override)
  SENSITIVE = []
  include Aws::Structure
end

#targetTypes::TargetDescription

The description of the target.



4826
4827
4828
4829
4830
4831
4832
4833
4834
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4826

class TargetHealthDescription < Struct.new(
  :target,
  :health_check_port,
  :target_health,
  :anomaly_detection,
  :administrative_override)
  SENSITIVE = []
  include Aws::Structure
end

#target_healthTypes::TargetHealth

The health information for the target.

Returns:



4826
4827
4828
4829
4830
4831
4832
4833
4834
# File 'lib/aws-sdk-elasticloadbalancingv2/types.rb', line 4826

class TargetHealthDescription < Struct.new(
  :target,
  :health_check_port,
  :target_health,
  :anomaly_detection,
  :administrative_override)
  SENSITIVE = []
  include Aws::Structure
end