Class: Aws::ElasticLoadBalancingV2::Waiters::LoadBalancerAvailable

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-elasticloadbalancingv2/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ LoadBalancerAvailable

Returns a new instance of LoadBalancerAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


88
89
# File 'lib/aws-sdk-elasticloadbalancingv2/waiters.rb', line 88

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



125
126
127
# File 'lib/aws-sdk-elasticloadbalancingv2/waiters.rb', line 125

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeLoadBalancersOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :load_balancer_arns (Array<String>)

    The Amazon Resource Names (ARN) of the load balancers. You can specify up to 20 load balancers in a single call.

  • :names (Array<String>)

    The names of the load balancers.

  • :marker (String)

    The marker for the next set of results. (You received this marker from a previous call.)

  • :page_size (Integer)

    The maximum number of results to return with this call.

Returns:



120
# File 'lib/aws-sdk-elasticloadbalancingv2/waiters.rb', line 120

def wait: (