Class: Aws::ElasticLoadBalancingV2::Waiters::LoadBalancerAvailable
- Inherits:
-
Object
- Object
- Aws::ElasticLoadBalancingV2::Waiters::LoadBalancerAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-elasticloadbalancingv2/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LoadBalancerAvailable
constructor
A new instance of LoadBalancerAvailable.
-
#wait(params = {}) ⇒ Types::DescribeLoadBalancersOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LoadBalancerAvailable
Returns a new instance of LoadBalancerAvailable.
88 89 |
# File 'lib/aws-sdk-elasticloadbalancingv2/waiters.rb', line 88
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
125 126 127 |
# File 'lib/aws-sdk-elasticloadbalancingv2/waiters.rb', line 125 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeLoadBalancersOutput
Returns a response object which responds to the following methods:
- #load_balancers => Array<Types::LoadBalancer>
- #next_marker => String
120 |
# File 'lib/aws-sdk-elasticloadbalancingv2/waiters.rb', line 120
def wait: (
|